/*
 * code-forensics
 * Copyright (C) 2016-2017 Silvio Montanari
 * Distributed under the GNU General Public License v3.0
 * see http://www.gnu.org/licenses/gpl.html
 */

module.exports = {
  Adapter:              require('./git_adapter'),
  LogStreamTransformer: require('./gitlog_stream_transformer')
};
